@@ -48,15 +48,18 @@ hledgerWebDev =
 -- Run normally.
 hledgerWebMain :: IO ()
 hledgerWebMain = do
+  -- try to encourage user's $PAGER to properly display ANSI (in command line help)
+  when useColorOnStdout setupPager
+
   wopts@WebOpts{cliopts_=copts@CliOpts{debug_, rawopts_}} <- getHledgerWebOpts
   when (debug_ > 0) $ printf "%s\n" prognameandversion >> printf "opts: %s\n" (show wopts)
   if
-    | "help"            `inRawOpts` rawopts_ -> putStr (showModeUsage webmode) >> exitSuccess
-    | "info"            `inRawOpts` rawopts_ -> runInfoForTopic "hledger-web" Nothing
-    | "man"             `inRawOpts` rawopts_ -> runManForTopic  "hledger-web" Nothing
-    | "version"         `inRawOpts` rawopts_ -> putStrLn prognameandversion >> exitSuccess
-    --  "binary-filename" `inRawOpts` rawopts_ -> putStrLn (binaryfilename progname)
-    | "test"            `inRawOpts` rawopts_ -> do
+    | boolopt "help"            rawopts_ -> pager (showModeUsage webmode) >> exitSuccess
+    | boolopt "info"            rawopts_ -> runInfoForTopic "hledger-web" Nothing
+    | boolopt "man"             rawopts_ -> runManForTopic  "hledger-web" Nothing
+    | boolopt "version"         rawopts_ -> putStrLn prognameandversion >> exitSuccess
+    -- boolopt "binary-filename" rawopts_ -> putStrLn (binaryfilename progname)
+    | boolopt "test"            rawopts_ -> do
       -- remove --test and --, leaving other args for hspec
       (`withArgs` hledgerWebTest) . filter (`notElem` ["--test","--"]) =<< getArgs
     | otherwise                              -> withJournalDo copts (web wopts)
@@ -64,8 +67,8 @@ hledgerWebMain = do
 -- | The hledger web command.
 web :: WebOpts -> Journal -> IO ()
 web opts j = do
-  let initq = _rsQuery . reportspec_ $ cliopts_ opts
-      j' = filterJournalTransactions initq j
+  let depthlessinitialq = filterQuery (not . queryIsDepth) . _rsQuery . reportspec_ $ cliopts_ opts
+      j' = filterJournalTransactions depthlessinitialq j
       h = host_ opts
       p = port_ opts
       u = base_url_ opts
